@@ -24,6 +24,7 @@ from alastria_service_client.validators import (
 )
 from alastria_identity.types import JwtToken, AlastriaToken
 from network_service_client.client import AClient as ANetworkClient, Client as NetworkClient, Network as NetworkDTO, NetworksNames
+from network_service_client.enums import ContractsNames
 
 
 class AlastriaAuthService(AAlastriaAuthService):
@@ -35,18 +36,16 @@ class AlastriaAuthService(AAlastriaAuthService):
     def get_did(address: str) -> str:
         alastria_service_client: AClient = Client(service_host=settings.ALASTRIA_SERVICE_HOST)
         network_data: NetworkDTO = NetworkClient(service_host=settings.NETWORK_SERVICE_HOST).get_network_by_name(NetworksNames.AlastriaDefaultName)
-        print(network_data)
         network_body = NetworkValidator(
-            provider=settings.ALASTRIA_NODE_PATH,
-            identity_manager_contract_address=settings.ALASTRIA_IDENTITY_MANAGER_CONTRACT_ADDRESS,  # TODO HOW MAKE THIS DATA DRIVEN ?
-            identity_manager_contract_abi=settings.ALASTRIA_IDENTITY_MANAGER_CONTRACT_ABI,  # TODO HOW MAKE THIS DATA DRIVEN ?
+            provider=network_data.node["path"],
+            identity_manager_contract_address=list(filter(lambda contract: contract["name"] == ContractsNames.AlastriaIdentityManager.value, network_data.contracts))[0]["address"],  
+            identity_manager_contract_abi=list(filter(lambda contract: contract["name"] == ContractsNames.AlastriaIdentityManager.value, network_data.contracts))[0]["abi"],  
             public_key_registry_contract_address="",
             public_key_registry_contract_abi="",
             credential_registry_contract_abi="",
             credential_registry_contract_address="",
-            chainId=settings.ALASTRIA_CHAIN_ID,  # TODO HOW MAKE THIS DATA DRIVEN ?
+            chainId=network_data.chain_id
         )
-
         return alastria_service_client.identity_keys(
             address=Address(address), body=OnlyNetworkValidator(network=network_body)
         ).response
